EventLog class

Constructors

EventLog(Map commonParams)

Properties

buildStartTime DateTime?
getter/setter pair
commonParams Map
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildFail(String code, String desc) Future
buildStart() → void
buildSuccess() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited